(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = global || self, global.rich = factory());
}(this, function () { 'use strict';

  var isObject = function (it) {
    return typeof it === 'object' ? it !== null : typeof it === 'function';
  };

  var toString = {}.toString;

  var classofRaw = function (it) {
    return toString.call(it).slice(8, -1);
  };

  // `IsArray` abstract operation
  // https://tc39.github.io/ecma262/#sec-isarray
  var isArray$1 = Array.isArray || function isArray(arg) {
    return classofRaw(arg) == 'Array';
  };

  var ceil = Math.ceil;
  var floor = Math.floor;

  // `ToInteger` abstract operation
  // https://tc39.github.io/ecma262/#sec-tointeger
  var toInteger = function (argument) {
    return isNaN(argument = +argument) ? 0 : (argument > 0 ? floor : ceil)(argument);
  };

  var max = Math.max;
  var min = Math.min;

  // Helper for a popular repeating case of the spec:
  // Let integer be ? ToInteger(index).
  // If integer < 0, let result be max((length + integer), 0); else let result be min(length, length).
  var toAbsoluteIndex = function (index, length) {
    var integer = toInteger(index);
    return integer < 0 ? max(integer + length, 0) : min(integer, length);
  };

  var min$1 = Math.min;

  // `ToLength` abstract operation
  // https://tc39.github.io/ecma262/#sec-tolength
  var toLength = function (argument) {
    return argument > 0 ? min$1(toInteger(argument), 0x1FFFFFFFFFFFFF) : 0; // 2 ** 53 - 1 == 9007199254740991
  };

  var fails = function (exec) {
    try {
      return !!exec();
    } catch (error) {
      return true;
    }
  };

  // fallback for non-array-like ES3 and non-enumerable old V8 strings


  var split = ''.split;

  var indexedObject = fails(function () {
    // throws an error in rhino, see https://github.com/mozilla/rhino/issues/346
    // eslint-disable-next-line no-prototype-builtins
    return !Object('z').propertyIsEnumerable(0);
  }) ? function (it) {
    return classofRaw(it) == 'String' ? split.call(it, '') : Object(it);
  } : Object;

  // `RequireObjectCoercible` abstract operation
  // https://tc39.github.io/ecma262/#sec-requireobjectcoercible
  var requireObjectCoercible = function (it) {
    if (it == undefined) throw TypeError("Can't call method on " + it);
    return it;
  };

  // toObject with fallback for non-array-like ES3 strings



  var toIndexedObject = function (it) {
    return indexedObject(requireObjectCoercible(it));
  };

  // 7.1.1 ToPrimitive(input [, PreferredType])

  // instead of the ES6 spec version, we didn't implement @@toPrimitive case
  // and the second argument - flag - preferred type is a string
  var toPrimitive = function (it, S) {
    if (!isObject(it)) return it;
    var fn, val;
    if (S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it))) return val;
    if (typeof (fn = it.valueOf) == 'function' && !isObject(val = fn.call(it))) return val;
    if (!S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it))) return val;
    throw TypeError("Can't convert object to primitive value");
  };

  // Thank's IE8 for his funny defineProperty
  var descriptors = !fails(function () {
    return Object.defineProperty({}, 'a', { get: function () { return 7; } }).a != 7;
  });

  // https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
  var global = typeof window == 'object' && window && window.Math == Math ? window
    : typeof self == 'object' && self && self.Math == Math ? self
    // eslint-disable-next-line no-new-func
    : Function('return this')();

  var document$1 = global.document;
  // typeof document.createElement is 'object' in old IE
  var exist = isObject(document$1) && isObject(document$1.createElement);

  var documentCreateElement = function (it) {
    return exist ? document$1.createElement(it) : {};
  };

  // Thank's IE8 for his funny defineProperty
  var ie8DomDefine = !descriptors && !fails(function () {
    return Object.defineProperty(documentCreateElement('div'), 'a', {
      get: function () { return 7; }
    }).a != 7;
  });

  var anObject = function (it) {
    if (!isObject(it)) {
      throw TypeError(String(it) + ' is not an object');
    } return it;
  };

  var nativeDefineProperty = Object.defineProperty;

  var f = descriptors ? nativeDefineProperty : function defineProperty(O, P, Attributes) {
    anObject(O);
    P = toPrimitive(P, true);
    anObject(Attributes);
    if (ie8DomDefine) try {
      return nativeDefineProperty(O, P, Attributes);
    } catch (error) { /* empty */ }
    if ('get' in Attributes || 'set' in Attributes) throw TypeError('Accessors not supported');
    if ('value' in Attributes) O[P] = Attributes.value;
    return O;
  };

  var objectDefineProperty = {
  	f: f
  };

  var createPropertyDescriptor = function (bitmap, value) {
    return {
      enumerable: !(bitmap & 1),
      configurable: !(bitmap & 2),
      writable: !(bitmap & 4),
      value: value
    };
  };

  var createProperty = function (object, key, value) {
    var propertyKey = toPrimitive(key);
    if (propertyKey in object) objectDefineProperty.f(object, propertyKey, createPropertyDescriptor(0, value));
    else object[propertyKey] = value;
  };

  function createCommonjsModule(fn, module) {
  	return module = { exports: {} }, fn(module, module.exports), module.exports;
  }

  var hide = descriptors ? function (object, key, value) {
    return objectDefineProperty.f(object, key, createPropertyDescriptor(1, value));
  } : function (object, key, value) {
    object[key] = value;
    return object;
  };

  var setGlobal = function (key, value) {
    try {
      hide(global, key, value);
    } catch (error) {
      global[key] = value;
    } return value;
  };

  var shared = createCommonjsModule(function (module) {
  var SHARED = '__core-js_shared__';
  var store = global[SHARED] || setGlobal(SHARED, {});

  (module.exports = function (key, value) {
    return store[key] || (store[key] = value !== undefined ? value : {});
  })('versions', []).push({
    version: '3.0.1',
    mode: 'global',
    copyright: '© 2019 Denis Pushkarev (zloirock.ru)'
  });
  });

  var id = 0;
  var postfix = Math.random();

  var uid = function (key) {
    return 'Symbol('.concat(key === undefined ? '' : key, ')_', (++id + postfix).toString(36));
  };

  // Chrome 38 Symbol has incorrect toString conversion
  var nativeSymbol = !fails(function () {
    // eslint-disable-next-line no-undef
    return !String(Symbol());
  });

  var store = shared('wks');

  var Symbol$1 = global.Symbol;


  var wellKnownSymbol = function (name) {
    return store[name] || (store[name] = nativeSymbol && Symbol$1[name]
      || (nativeSymbol ? Symbol$1 : uid)('Symbol.' + name));
  };

  var SPECIES = wellKnownSymbol('species');

  var arrayMethodHasSpeciesSupport = function (METHOD_NAME) {
    return !fails(function () {
      var array = [];
      var constructor = array.constructor = {};
      constructor[SPECIES] = function () {
        return { foo: 1 };
      };
      return array[METHOD_NAME](Boolean).foo !== 1;
    });
  };

  var nativePropertyIsEnumerable = {}.propertyIsEnumerable;
  var nativeGetOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

  // Nashorn ~ JDK8 bug
  var NASHORN_BUG = nativeGetOwnPropertyDescriptor && !nativePropertyIsEnumerable.call({ 1: 2 }, 1);

  var f$1 = NASHORN_BUG ? function propertyIsEnumerable(V) {
    var descriptor = nativeGetOwnPropertyDescriptor(this, V);
    return !!descriptor && descriptor.enumerable;
  } : nativePropertyIsEnumerable;

  var objectPropertyIsEnumerable = {
  	f: f$1
  };

  var hasOwnProperty = {}.hasOwnProperty;

  var has = function (it, key) {
    return hasOwnProperty.call(it, key);
  };

  var nativeGetOwnPropertyDescriptor$1 = Object.getOwnPropertyDescriptor;

  var f$2 = descriptors ? nativeGetOwnPropertyDescriptor$1 : function getOwnPropertyDescriptor(O, P) {
    O = toIndexedObject(O);
    P = toPrimitive(P, true);
    if (ie8DomDefine) try {
      return nativeGetOwnPropertyDescriptor$1(O, P);
    } catch (error) { /* empty */ }
    if (has(O, P)) return createPropertyDescriptor(!objectPropertyIsEnumerable.f.call(O, P), O[P]);
  };

  var objectGetOwnPropertyDescriptor = {
  	f: f$2
  };

  var functionToString = shared('native-function-to-string', Function.toString);

  var WeakMap = global.WeakMap;

  var nativeWeakMap = typeof WeakMap === 'function' && /native code/.test(functionToString.call(WeakMap));

  var shared$1 = shared('keys');


  var sharedKey = function (key) {
    return shared$1[key] || (shared$1[key] = uid(key));
  };

  var hiddenKeys = {};

  var WeakMap$1 = global.WeakMap;
  var set, get, has$1;

  var enforce = function (it) {
    return has$1(it) ? get(it) : set(it, {});
  };

  var getterFor = function (TYPE) {
    return function (it) {
      var state;
      if (!isObject(it) || (state = get(it)).type !== TYPE) {
        throw TypeError('Incompatible receiver, ' + TYPE + ' required');
      } return state;
    };
  };

  if (nativeWeakMap) {
    var store$1 = new WeakMap$1();
    var wmget = store$1.get;
    var wmhas = store$1.has;
    var wmset = store$1.set;
    set = function (it, metadata) {
      wmset.call(store$1, it, metadata);
      return metadata;
    };
    get = function (it) {
      return wmget.call(store$1, it) || {};
    };
    has$1 = function (it) {
      return wmhas.call(store$1, it);
    };
  } else {
    var STATE = sharedKey('state');
    hiddenKeys[STATE] = true;
    set = function (it, metadata) {
      hide(it, STATE, metadata);
      return metadata;
    };
    get = function (it) {
      return has(it, STATE) ? it[STATE] : {};
    };
    has$1 = function (it) {
      return has(it, STATE);
    };
  }

  var internalState = {
    set: set,
    get: get,
    has: has$1,
    enforce: enforce,
    getterFor: getterFor
  };

  var redefine = createCommonjsModule(function (module) {
  var getInternalState = internalState.get;
  var enforceInternalState = internalState.enforce;
  var TEMPLATE = String(functionToString).split('toString');

  shared('inspectSource', function (it) {
    return functionToString.call(it);
  });

  (module.exports = function (O, key, value, options) {
    var unsafe = options ? !!options.unsafe : false;
    var simple = options ? !!options.enumerable : false;
    var noTargetGet = options ? !!options.noTargetGet : false;
    if (typeof value == 'function') {
      if (typeof key == 'string' && !has(value, 'name')) hide(value, 'name', key);
      enforceInternalState(value).source = TEMPLATE.join(typeof key == 'string' ? key : '');
    }
    if (O === global) {
      if (simple) O[key] = value;
      else setGlobal(key, value);
      return;
    } else if (!unsafe) {
      delete O[key];
    } else if (!noTargetGet && O[key]) {
      simple = true;
    }
    if (simple) O[key] = value;
    else hide(O, key, value);
  // add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
  })(Function.prototype, 'toString', function toString() {
    return typeof this == 'function' && getInternalState(this).source || functionToString.call(this);
  });
  });

  // `Array.prototype.{ indexOf, includes }` methods implementation
  // false -> Array#indexOf
  // https://tc39.github.io/ecma262/#sec-array.prototype.indexof
  // true  -> Array#includes
  // https://tc39.github.io/ecma262/#sec-array.prototype.includes
  var arrayIncludes = function (IS_INCLUDES) {
    return function ($this, el, fromIndex) {
      var O = toIndexedObject($this);
      var length = toLength(O.length);
      var index = toAbsoluteIndex(fromIndex, length);
      var value;
      // Array#includes uses SameValueZero equality algorithm
      // eslint-disable-next-line no-self-compare
      if (IS_INCLUDES && el != el) while (length > index) {
        value = O[index++];
        // eslint-disable-next-line no-self-compare
        if (value != value) return true;
      // Array#indexOf ignores holes, Array#includes - not
      } else for (;length > index; index++) if (IS_INCLUDES || index in O) {
        if (O[index] === el) return IS_INCLUDES || index || 0;
      } return !IS_INCLUDES && -1;
    };
  };

  var arrayIndexOf = arrayIncludes(false);


  var objectKeysInternal = function (object, names) {
    var O = toIndexedObject(object);
    var i = 0;
    var result = [];
    var key;
    for (key in O) !has(hiddenKeys, key) && has(O, key) && result.push(key);
    // Don't enum bug & hidden keys
    while (names.length > i) if (has(O, key = names[i++])) {
      ~arrayIndexOf(result, key) || result.push(key);
    }
    return result;
  };

  // IE8- don't enum bug keys
  var enumBugKeys = [
    'constructor',
    'hasOwnProperty',
    'isPrototypeOf',
    'propertyIsEnumerable',
    'toLocaleString',
    'toString',
    'valueOf'
  ];

  // 19.1.2.7 / 15.2.3.4 Object.getOwnPropertyNames(O)

  var hiddenKeys$1 = enumBugKeys.concat('length', 'prototype');

  var f$3 = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
    return objectKeysInternal(O, hiddenKeys$1);
  };

  var objectGetOwnPropertyNames = {
  	f: f$3
  };

  var f$4 = Object.getOwnPropertySymbols;

  var objectGetOwnPropertySymbols = {
  	f: f$4
  };

  var Reflect = global.Reflect;

  // all object keys, includes non-enumerable and symbols
  var ownKeys = Reflect && Reflect.ownKeys || function ownKeys(it) {
    var keys = objectGetOwnPropertyNames.f(anObject(it));
    var getOwnPropertySymbols = objectGetOwnPropertySymbols.f;
    return getOwnPropertySymbols ? keys.concat(getOwnPropertySymbols(it)) : keys;
  };

  var copyConstructorProperties = function (target, source) {
    var keys = ownKeys(source);
    var defineProperty = objectDefineProperty.f;
    var getOwnPropertyDescriptor = objectGetOwnPropertyDescriptor.f;
    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];
      if (!has(target, key)) defineProperty(target, key, getOwnPropertyDescriptor(source, key));
    }
  };

  var replacement = /#|\.prototype\./;

  var isForced = function (feature, detection) {
    var value = data[normalize(feature)];
    return value == POLYFILL ? true
      : value == NATIVE ? false
      : typeof detection == 'function' ? fails(detection)
      : !!detection;
  };

  var normalize = isForced.normalize = function (string) {
    return String(string).replace(replacement, '.').toLowerCase();
  };

  var data = isForced.data = {};
  var NATIVE = isForced.NATIVE = 'N';
  var POLYFILL = isForced.POLYFILL = 'P';

  var isForced_1 = isForced;

  var getOwnPropertyDescriptor = objectGetOwnPropertyDescriptor.f;






  /*
    options.target      - name of the target object
    options.global      - target is the global object
    options.stat        - export as static methods of target
    options.proto       - export as prototype methods of target
    options.real        - real prototype method for the `pure` version
    options.forced      - export even if the native feature is available
    options.bind        - bind methods to the target, required for the `pure` version
    options.wrap        - wrap constructors to preventing global pollution, required for the `pure` version
    options.unsafe      - use the simple assignment of property instead of delete + defineProperty
    options.sham        - add a flag to not completely full polyfills
    options.enumerable  - export as enumerable property
    options.noTargetGet - prevent calling a getter on target
  */
  var _export = function (options, source) {
    var TARGET = options.target;
    var GLOBAL = options.global;
    var STATIC = options.stat;
    var FORCED, target, key, targetProperty, sourceProperty, descriptor;
    if (GLOBAL) {
      target = global;
    } else if (STATIC) {
      target = global[TARGET] || setGlobal(TARGET, {});
    } else {
      target = (global[TARGET] || {}).prototype;
    }
    if (target) for (key in source) {
      sourceProperty = source[key];
      if (options.noTargetGet) {
        descriptor = getOwnPropertyDescriptor(target, key);
        targetProperty = descriptor && descriptor.value;
      } else targetProperty = target[key];
      FORCED = isForced_1(GLOBAL ? key : TARGET + (STATIC ? '.' : '#') + key, options.forced);
      // contained in target
      if (!FORCED && targetProperty !== undefined) {
        if (typeof sourceProperty === typeof targetProperty) continue;
        copyConstructorProperties(sourceProperty, targetProperty);
      }
      // add a flag to not completely full polyfills
      if (options.sham || (targetProperty && targetProperty.sham)) {
        hide(sourceProperty, 'sham', true);
      }
      // extend global
      redefine(target, key, sourceProperty, options);
    }
  };

  var SPECIES$1 = wellKnownSymbol('species');
  var nativeSlice = [].slice;
  var max$1 = Math.max;

  var SPECIES_SUPPORT = arrayMethodHasSpeciesSupport('slice');

  // `Array.prototype.slice` method
  // https://tc39.github.io/ecma262/#sec-array.prototype.slice
  // fallback for not array-like ES3 strings and DOM objects
  _export({ target: 'Array', proto: true, forced: !SPECIES_SUPPORT }, {
    slice: function slice(start, end) {
      var O = toIndexedObject(this);
      var length = toLength(O.length);
      var k = toAbsoluteIndex(start, length);
      var fin = toAbsoluteIndex(end === undefined ? length : end, length);
      // inline `ArraySpeciesCreate` for usage native `Array#slice` where it's possible
      var Constructor, result, n;
      if (isArray$1(O)) {
        Constructor = O.constructor;
        // cross-realm fallback
        if (typeof Constructor == 'function' && (Constructor === Array || isArray$1(Constructor.prototype))) {
          Constructor = undefined;
        } else if (isObject(Constructor)) {
          Constructor = Constructor[SPECIES$1];
          if (Constructor === null) Constructor = undefined;
        }
        if (Constructor === Array || Constructor === undefined) {
          return nativeSlice.call(O, k, fin);
        }
      }
      result = new (Constructor === undefined ? Array : Constructor)(max$1(fin - k, 0));
      for (n = 0; k < fin; k++, n++) if (k in O) createProperty(result, n, O[k]);
      result.length = n;
      return result;
    }
  });

  // 19.1.2.14 / 15.2.3.14 Object.keys(O)



  var objectKeys = Object.keys || function keys(O) {
    return objectKeysInternal(O, enumBugKeys);
  };

  // `ToObject` abstract operation
  // https://tc39.github.io/ecma262/#sec-toobject
  var toObject = function (argument) {
    return Object(requireObjectCoercible(argument));
  };

  // 19.1.2.1 Object.assign(target, source, ...)





  var nativeAssign = Object.assign;

  // should work with symbols and should have deterministic property order (V8 bug)
  var objectAssign = !nativeAssign || fails(function () {
    var A = {};
    var B = {};
    // eslint-disable-next-line no-undef
    var symbol = Symbol();
    var alphabet = 'abcdefghijklmnopqrst';
    A[symbol] = 7;
    alphabet.split('').forEach(function (chr) { B[chr] = chr; });
    return nativeAssign({}, A)[symbol] != 7 || objectKeys(nativeAssign({}, B)).join('') != alphabet;
  }) ? function assign(target, source) { // eslint-disable-line no-unused-vars
    var T = toObject(target);
    var argumentsLength = arguments.length;
    var index = 1;
    var getOwnPropertySymbols = objectGetOwnPropertySymbols.f;
    var propertyIsEnumerable = objectPropertyIsEnumerable.f;
    while (argumentsLength > index) {
      var S = indexedObject(arguments[index++]);
      var keys = getOwnPropertySymbols ? objectKeys(S).concat(getOwnPropertySymbols(S)) : objectKeys(S);
      var length = keys.length;
      var j = 0;
      var key;
      while (length > j) if (propertyIsEnumerable.call(S, key = keys[j++])) T[key] = S[key];
    } return T;
  } : nativeAssign;

  // `Object.assign` method
  // https://tc39.github.io/ecma262/#sec-object.assign
  _export({ target: 'Object', stat: true, forced: Object.assign !== objectAssign }, { assign: objectAssign });

  var MATCH = wellKnownSymbol('match');

  // `IsRegExp` abstract operation
  // https://tc39.github.io/ecma262/#sec-isregexp
  var isRegexp = function (it) {
    var isRegExp;
    return isObject(it) && ((isRegExp = it[MATCH]) !== undefined ? !!isRegExp : classofRaw(it) == 'RegExp');
  };

  var aFunction = function (it) {
    if (typeof it != 'function') {
      throw TypeError(String(it) + ' is not a function');
    } return it;
  };

  var SPECIES$2 = wellKnownSymbol('species');

  // `SpeciesConstructor` abstract operation
  // https://tc39.github.io/ecma262/#sec-speciesconstructor
  var speciesConstructor = function (O, defaultConstructor) {
    var C = anObject(O).constructor;
    var S;
    return C === undefined || (S = anObject(C)[SPECIES$2]) == undefined ? defaultConstructor : aFunction(S);
  };

  // CONVERT_TO_STRING: true  -> String#at
  // CONVERT_TO_STRING: false -> String#codePointAt
  var stringAt = function (that, pos, CONVERT_TO_STRING) {
    var S = String(requireObjectCoercible(that));
    var position = toInteger(pos);
    var size = S.length;
    var first, second;
    if (position < 0 || position >= size) return CONVERT_TO_STRING ? '' : undefined;
    first = S.charCodeAt(position);
    return first < 0xD800 || first > 0xDBFF || position + 1 === size
      || (second = S.charCodeAt(position + 1)) < 0xDC00 || second > 0xDFFF
        ? CONVERT_TO_STRING ? S.charAt(position) : first
        : CONVERT_TO_STRING ? S.slice(position, position + 2) : (first - 0xD800 << 10) + (second - 0xDC00) + 0x10000;
  };

  // `AdvanceStringIndex` abstract operation
  // https://tc39.github.io/ecma262/#sec-advancestringindex
  var advanceStringIndex = function (S, index, unicode) {
    return index + (unicode ? stringAt(S, index, true).length : 1);
  };

  // `RegExp.prototype.flags` getter implementation
  // https://tc39.github.io/ecma262/#sec-get-regexp.prototype.flags
  var regexpFlags = function () {
    var that = anObject(this);
    var result = '';
    if (that.global) result += 'g';
    if (that.ignoreCase) result += 'i';
    if (that.multiline) result += 'm';
    if (that.unicode) result += 'u';
    if (that.sticky) result += 'y';
    return result;
  };

  var nativeExec = RegExp.prototype.exec;
  // This always refers to the native implementation, because the
  // String#replace polyfill uses ./fix-regexp-well-known-symbol-logic.js,
  // which loads this file before patching the method.
  var nativeReplace = String.prototype.replace;

  var patchedExec = nativeExec;

  var UPDATES_LAST_INDEX_WRONG = (function () {
    var re1 = /a/;
    var re2 = /b*/g;
    nativeExec.call(re1, 'a');
    nativeExec.call(re2, 'a');
    return re1.lastIndex !== 0 || re2.lastIndex !== 0;
  })();

  // nonparticipating capturing group, copied from es5-shim's String#split patch.
  var NPCG_INCLUDED = /()??/.exec('')[1] !== undefined;

  var PATCH = UPDATES_LAST_INDEX_WRONG || NPCG_INCLUDED;

  if (PATCH) {
    patchedExec = function exec(str) {
      var re = this;
      var lastIndex, reCopy, match, i;

      if (NPCG_INCLUDED) {
        reCopy = new RegExp('^' + re.source + '$(?!\\s)', regexpFlags.call(re));
      }
      if (UPDATES_LAST_INDEX_WRONG) lastIndex = re.lastIndex;

      match = nativeExec.call(re, str);

      if (UPDATES_LAST_INDEX_WRONG && match) {
        re.lastIndex = re.global ? match.index + match[0].length : lastIndex;
      }
      if (NPCG_INCLUDED && match && match.length > 1) {
        // Fix browsers whose `exec` methods don't consistently return `undefined`
        // for NPCG, like IE8. NOTE: This doesn' work for /(.?)?/
        nativeReplace.call(match[0], reCopy, function () {
          for (i = 1; i < arguments.length - 2; i++) {
            if (arguments[i] === undefined) match[i] = undefined;
          }
        });
      }

      return match;
    };
  }

  var regexpExec = patchedExec;

  // `RegExpExec` abstract operation
  // https://tc39.github.io/ecma262/#sec-regexpexec
  var regexpExecAbstract = function (R, S) {
    var exec = R.exec;
    if (typeof exec === 'function') {
      var result = exec.call(R, S);
      if (typeof result !== 'object') {
        throw TypeError('RegExp exec method returned something other than an Object or null');
      }
      return result;
    }

    if (classofRaw(R) !== 'RegExp') {
      throw TypeError('RegExp#exec called on incompatible receiver');
    }

    return regexpExec.call(R, S);
  };

  var SPECIES$3 = wellKnownSymbol('species');

  var REPLACE_SUPPORTS_NAMED_GROUPS = !fails(function () {
    // #replace needs built-in support for named groups.
    // #match works fine because it just return the exec results, even if it has
    // a "grops" property.
    var re = /./;
    re.exec = function () {
      var result = [];
      result.groups = { a: '7' };
      return result;
    };
    return ''.replace(re, '$<a>') !== '7';
  });

  // Chrome 51 has a buggy "split" implementation when RegExp#exec !== nativeExec
  // Weex JS has frozen built-in prototypes, so use try / catch wrapper
  var SPLIT_WORKS_WITH_OVERWRITTEN_EXEC = !fails(function () {
    var re = /(?:)/;
    var originalExec = re.exec;
    re.exec = function () { return originalExec.apply(this, arguments); };
    var result = 'ab'.split(re);
    return result.length !== 2 || result[0] !== 'a' || result[1] !== 'b';
  });

  var fixRegexpWellKnownSymbolLogic = function (KEY, length, exec, sham) {
    var SYMBOL = wellKnownSymbol(KEY);

    var DELEGATES_TO_SYMBOL = !fails(function () {
      // String methods call symbol-named RegEp methods
      var O = {};
      O[SYMBOL] = function () { return 7; };
      return ''[KEY](O) != 7;
    });

    var DELEGATES_TO_EXEC = DELEGATES_TO_SYMBOL && !fails(function () {
      // Symbol-named RegExp methods call .exec
      var execCalled = false;
      var re = /a/;
      re.exec = function () { execCalled = true; return null; };

      if (KEY === 'split') {
        // RegExp[@@split] doesn't call the regex's exec method, but first creates
        // a new one. We need to return the patched regex when creating the new one.
        re.constructor = {};
        re.constructor[SPECIES$3] = function () { return re; };
      }

      re[SYMBOL]('');
      return !execCalled;
    });

    if (
      !DELEGATES_TO_SYMBOL ||
      !DELEGATES_TO_EXEC ||
      (KEY === 'replace' && !REPLACE_SUPPORTS_NAMED_GROUPS) ||
      (KEY === 'split' && !SPLIT_WORKS_WITH_OVERWRITTEN_EXEC)
    ) {
      var nativeRegExpMethod = /./[SYMBOL];
      var methods = exec(SYMBOL, ''[KEY], function (nativeMethod, regexp, str, arg2, forceStringMethod) {
        if (regexp.exec === regexpExec) {
          if (DELEGATES_TO_SYMBOL && !forceStringMethod) {
            // The native String method already delegates to @@method (this
            // polyfilled function), leasing to infinite recursion.
            // We avoid it by directly calling the native @@method method.
            return { done: true, value: nativeRegExpMethod.call(regexp, str, arg2) };
          }
          return { done: true, value: nativeMethod.call(str, regexp, arg2) };
        }
        return { done: false };
      });
      var stringMethod = methods[0];
      var regexMethod = methods[1];

      redefine(String.prototype, KEY, stringMethod);
      redefine(RegExp.prototype, SYMBOL, length == 2
        // 21.2.5.8 RegExp.prototype[@@replace](string, replaceValue)
        // 21.2.5.11 RegExp.prototype[@@split](string, limit)
        ? function (string, arg) { return regexMethod.call(string, this, arg); }
        // 21.2.5.6 RegExp.prototype[@@match](string)
        // 21.2.5.9 RegExp.prototype[@@search](string)
        : function (string) { return regexMethod.call(string, this); }
      );
      if (sham) hide(RegExp.prototype[SYMBOL], 'sham', true);
    }
  };

  var arrayPush = [].push;
  var min$2 = Math.min;
  var MAX_UINT32 = 0xFFFFFFFF;

  // babel-minify transpiles RegExp('x', 'y') -> /x/y and it causes SyntaxError
  var SUPPORTS_Y = !fails(function () { return !RegExp(MAX_UINT32, 'y'); });

  // @@split logic
  fixRegexpWellKnownSymbolLogic(
    'split',
    2,
    function (SPLIT, nativeSplit, maybeCallNative) {
      var internalSplit;
      if (
        'abbc'.split(/(b)*/)[1] == 'c' ||
        'test'.split(/(?:)/, -1).length != 4 ||
        'ab'.split(/(?:ab)*/).length != 2 ||
        '.'.split(/(.?)(.?)/).length != 4 ||
        '.'.split(/()()/).length > 1 ||
        ''.split(/.?/).length
      ) {
        // based on es5-shim implementation, need to rework it
        internalSplit = function (separator, limit) {
          var string = String(requireObjectCoercible(this));
          var lim = limit === undefined ? MAX_UINT32 : limit >>> 0;
          if (lim === 0) return [];
          if (separator === undefined) return [string];
          // If `separator` is not a regex, use native split
          if (!isRegexp(separator)) {
            return nativeSplit.call(string, separator, lim);
          }
          var output = [];
          var flags = (separator.ignoreCase ? 'i' : '') +
                      (separator.multiline ? 'm' : '') +
                      (separator.unicode ? 'u' : '') +
                      (separator.sticky ? 'y' : '');
          var lastLastIndex = 0;
          // Make `global` and avoid `lastIndex` issues by working with a copy
          var separatorCopy = new RegExp(separator.source, flags + 'g');
          var match, lastIndex, lastLength;
          while (match = regexpExec.call(separatorCopy, string)) {
            lastIndex = separatorCopy.lastIndex;
            if (lastIndex > lastLastIndex) {
              output.push(string.slice(lastLastIndex, match.index));
              if (match.length > 1 && match.index < string.length) arrayPush.apply(output, match.slice(1));
              lastLength = match[0].length;
              lastLastIndex = lastIndex;
              if (output.length >= lim) break;
            }
            if (separatorCopy.lastIndex === match.index) separatorCopy.lastIndex++; // Avoid an infinite loop
          }
          if (lastLastIndex === string.length) {
            if (lastLength || !separatorCopy.test('')) output.push('');
          } else output.push(string.slice(lastLastIndex));
          return output.length > lim ? output.slice(0, lim) : output;
        };
      // Chakra, V8
      } else if ('0'.split(undefined, 0).length) {
        internalSplit = function (separator, limit) {
          return separator === undefined && limit === 0 ? [] : nativeSplit.call(this, separator, limit);
        };
      } else internalSplit = nativeSplit;

      return [
        // `String.prototype.split` method
        // https://tc39.github.io/ecma262/#sec-string.prototype.split
        function split(separator, limit) {
          var O = requireObjectCoercible(this);
          var splitter = separator == undefined ? undefined : separator[SPLIT];
          return splitter !== undefined
            ? splitter.call(separator, O, limit)
            : internalSplit.call(String(O), separator, limit);
        },
        // `RegExp.prototype[@@split]` method
        // https://tc39.github.io/ecma262/#sec-regexp.prototype-@@split
        //
        // NOTE: This cannot be properly polyfilled in engines that don't support
        // the 'y' flag.
        function (regexp, limit) {
          var res = maybeCallNative(internalSplit, regexp, this, limit, internalSplit !== nativeSplit);
          if (res.done) return res.value;

          var rx = anObject(regexp);
          var S = String(this);
          var C = speciesConstructor(rx, RegExp);

          var unicodeMatching = rx.unicode;
          var flags = (rx.ignoreCase ? 'i' : '') +
                      (rx.multiline ? 'm' : '') +
                      (rx.unicode ? 'u' : '') +
                      (SUPPORTS_Y ? 'y' : 'g');

          // ^(? + rx + ) is needed, in combination with some S slicing, to
          // simulate the 'y' flag.
          var splitter = new C(SUPPORTS_Y ? rx : '^(?:' + rx.source + ')', flags);
          var lim = limit === undefined ? MAX_UINT32 : limit >>> 0;
          if (lim === 0) return [];
          if (S.length === 0) return regexpExecAbstract(splitter, S) === null ? [S] : [];
          var p = 0;
          var q = 0;
          var A = [];
          while (q < S.length) {
            splitter.lastIndex = SUPPORTS_Y ? q : 0;
            var z = regexpExecAbstract(splitter, SUPPORTS_Y ? S : S.slice(q));
            var e;
            if (
              z === null ||
              (e = min$2(toLength(splitter.lastIndex + (SUPPORTS_Y ? 0 : q)), S.length)) === p
            ) {
              q = advanceStringIndex(S, q, unicodeMatching);
            } else {
              A.push(S.slice(p, q));
              if (A.length === lim) return A;
              for (var i = 1; i <= z.length - 1; i++) {
                A.push(z[i]);
                if (A.length === lim) return A;
              }
              q = p = e;
            }
          }
          A.push(S.slice(p));
          return A;
        }
      ];
    },
    !SUPPORTS_Y
  );

  var quot = /"/g;

  // B.2.3.2.1 CreateHTML(string, tag, attribute, value)
  // https://tc39.github.io/ecma262/#sec-createhtml
  var createHtml = function (string, tag, attribute, value) {
    var S = String(requireObjectCoercible(string));
    var p1 = '<' + tag;
    if (attribute !== '') p1 += ' ' + attribute + '="' + String(value).replace(quot, '&quot;') + '"';
    return p1 + '>' + S + '</' + tag + '>';
  };

  // check the existence of a method, lowercase
  // of a tag and escaping quotes in arguments
  var forcedStringHtmlMethod = function (METHOD_NAME) {
    return fails(function () {
      var test = ''[METHOD_NAME]('"');
      return test !== test.toLowerCase() || test.split('"').length > 3;
    });
  };

  var FORCED = forcedStringHtmlMethod('bold');

  // `String.prototype.bold` method
  // https://tc39.github.io/ecma262/#sec-string.prototype.bold
  _export({ target: 'String', proto: true, forced: FORCED }, {
    bold: function bold() {
      return createHtml(this, 'b', '', '');
    }
  });

  var FORCED$1 = forcedStringHtmlMethod('link');

  // `String.prototype.link` method
  // https://tc39.github.io/ecma262/#sec-string.prototype.link
  _export({ target: 'String', proto: true, forced: FORCED$1 }, {
    link: function link(url) {
      return createHtml(this, 'a', 'href', url);
    }
  });

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    subClass.__proto__ = superClass;
  }

  var sloppyArrayMethod = function (METHOD_NAME, argument) {
    var method = [][METHOD_NAME];
    return !method || !fails(function () {
      // eslint-disable-next-line no-useless-call,no-throw-literal
      method.call(null, argument || function () { throw 1; }, 1);
    });
  };

  var nativeJoin = [].join;

  var ES3_STRINGS = indexedObject != Object;
  var SLOPPY_METHOD = sloppyArrayMethod('join', ',');

  // `Array.prototype.join` method
  // https://tc39.github.io/ecma262/#sec-array.prototype.join
  _export({ target: 'Array', proto: true, forced: ES3_STRINGS || SLOPPY_METHOD }, {
    join: function join(separator) {
      return nativeJoin.call(toIndexedObject(this), separator === undefined ? ',' : separator);
    }
  });

  // optional / simple context binding
  var bindContext = function (fn, that, length) {
    aFunction(fn);
    if (that === undefined) return fn;
    switch (length) {
      case 0: return function () {
        return fn.call(that);
      };
      case 1: return function (a) {
        return fn.call(that, a);
      };
      case 2: return function (a, b) {
        return fn.call(that, a, b);
      };
      case 3: return function (a, b, c) {
        return fn.call(that, a, b, c);
      };
    }
    return function (/* ...args */) {
      return fn.apply(that, arguments);
    };
  };

  var SPECIES$4 = wellKnownSymbol('species');

  // `ArraySpeciesCreate` abstract operation
  // https://tc39.github.io/ecma262/#sec-arrayspeciescreate
  var arraySpeciesCreate = function (originalArray, length) {
    var C;
    if (isArray$1(originalArray)) {
      C = originalArray.constructor;
      // cross-realm fallback
      if (typeof C == 'function' && (C === Array || isArray$1(C.prototype))) C = undefined;
      else if (isObject(C)) {
        C = C[SPECIES$4];
        if (C === null) C = undefined;
      }
    } return new (C === undefined ? Array : C)(length === 0 ? 0 : length);
  };

  // `Array.prototype.{ forEach, map, filter, some, every, find, findIndex }` methods implementation
  // 0 -> Array#forEach
  // https://tc39.github.io/ecma262/#sec-array.prototype.foreach
  // 1 -> Array#map
  // https://tc39.github.io/ecma262/#sec-array.prototype.map
  // 2 -> Array#filter
  // https://tc39.github.io/ecma262/#sec-array.prototype.filter
  // 3 -> Array#some
  // https://tc39.github.io/ecma262/#sec-array.prototype.some
  // 4 -> Array#every
  // https://tc39.github.io/ecma262/#sec-array.prototype.every
  // 5 -> Array#find
  // https://tc39.github.io/ecma262/#sec-array.prototype.find
  // 6 -> Array#findIndex
  // https://tc39.github.io/ecma262/#sec-array.prototype.findIndex
  var arrayMethods = function (TYPE, specificCreate) {
    var IS_MAP = TYPE == 1;
    var IS_FILTER = TYPE == 2;
    var IS_SOME = TYPE == 3;
    var IS_EVERY = TYPE == 4;
    var IS_FIND_INDEX = TYPE == 6;
    var NO_HOLES = TYPE == 5 || IS_FIND_INDEX;
    var create = specificCreate || arraySpeciesCreate;
    return function ($this, callbackfn, that) {
      var O = toObject($this);
      var self = indexedObject(O);
      var boundFunction = bindContext(callbackfn, that, 3);
      var length = toLength(self.length);
      var index = 0;
      var target = IS_MAP ? create($this, length) : IS_FILTER ? create($this, 0) : undefined;
      var value, result;
      for (;length > index; index++) if (NO_HOLES || index in self) {
        value = self[index];
        result = boundFunction(value, index, O);
        if (TYPE) {
          if (IS_MAP) target[index] = result; // map
          else if (result) switch (TYPE) {
            case 3: return true;              // some
            case 5: return value;             // find
            case 6: return index;             // findIndex
            case 2: target.push(value);       // filter
          } else if (IS_EVERY) return false;  // every
        }
      }
      return IS_FIND_INDEX ? -1 : IS_SOME || IS_EVERY ? IS_EVERY : target;
    };
  };

  var internalMap = arrayMethods(1);

  var SPECIES_SUPPORT$1 = arrayMethodHasSpeciesSupport('map');

  // `Array.prototype.map` method
  // https://tc39.github.io/ecma262/#sec-array.prototype.map
  // with adding support of @@species
  _export({ target: 'Array', proto: true, forced: !SPECIES_SUPPORT$1 }, {
    map: function map(callbackfn /* , thisArg */) {
      return internalMap(this, callbackfn, arguments[1]);
    }
  });

  var FAILS_ON_PRIMITIVES = fails(function () { objectKeys(1); });

  // `Object.keys` method
  // https://tc39.github.io/ecma262/#sec-object.keys
  _export({ target: 'Object', stat: true, forced: FAILS_ON_PRIMITIVES }, {
    keys: function keys(it) {
      return objectKeys(toObject(it));
    }
  });

  // iterable DOM collections
  // flag - `iterable` interface - 'entries', 'keys', 'values', 'forEach' methods
  var domIterables = {
    CSSRuleList: 0,
    CSSStyleDeclaration: 0,
    CSSValueList: 0,
    ClientRectList: 0,
    DOMRectList: 0,
    DOMStringList: 0,
    DOMTokenList: 1,
    DataTransferItemList: 0,
    FileList: 0,
    HTMLAllCollection: 0,
    HTMLCollection: 0,
    HTMLFormElement: 0,
    HTMLSelectElement: 0,
    MediaList: 0,
    MimeTypeArray: 0,
    NamedNodeMap: 0,
    NodeList: 1,
    PaintRequestList: 0,
    Plugin: 0,
    PluginArray: 0,
    SVGLengthList: 0,
    SVGNumberList: 0,
    SVGPathSegList: 0,
    SVGPointList: 0,
    SVGStringList: 0,
    SVGTransformList: 0,
    SourceBufferList: 0,
    StyleSheetList: 0,
    TextTrackCueList: 0,
    TextTrackList: 0,
    TouchList: 0
  };

  var nativeForEach = [].forEach;
  var internalForEach = arrayMethods(0);

  var SLOPPY_METHOD$1 = sloppyArrayMethod('forEach');

  // `Array.prototype.forEach` method implementation
  // https://tc39.github.io/ecma262/#sec-array.prototype.foreach
  var arrayForEach = SLOPPY_METHOD$1 ? function forEach(callbackfn /* , thisArg */) {
    return internalForEach(this, callbackfn, arguments[1]);
  } : nativeForEach;

  for (var COLLECTION_NAME in domIterables) {
    var Collection = global[COLLECTION_NAME];
    var CollectionPrototype = Collection && Collection.prototype;
    // some Chrome versions have non-configurable methods on DOMTokenList
    if (CollectionPrototype && CollectionPrototype.forEach !== arrayForEach) try {
      hide(CollectionPrototype, 'forEach', arrayForEach);
    } catch (error) {
      CollectionPrototype.forEach = arrayForEach;
    }
  }

  var TO_STRING_TAG = wellKnownSymbol('toStringTag');
  // ES3 wrong here
  var CORRECT_ARGUMENTS = classofRaw(function () { return arguments; }()) == 'Arguments';

  // fallback for IE11 Script Access Denied error
  var tryGet = function (it, key) {
    try {
      return it[key];
    } catch (error) { /* empty */ }
  };

  // getting tag from ES6+ `Object.prototype.toString`
  var classof = function (it) {
    var O, tag, result;
    return it === undefined ? 'Undefined' : it === null ? 'Null'
      // @@toStringTag case
      : typeof (tag = tryGet(O = Object(it), TO_STRING_TAG)) == 'string' ? tag
      // builtinTag case
      : CORRECT_ARGUMENTS ? classofRaw(O)
      // ES3 arguments fallback
      : (result = classofRaw(O)) == 'Object' && typeof O.callee == 'function' ? 'Arguments' : result;
  };

  var TO_STRING_TAG$1 = wellKnownSymbol('toStringTag');
  var test = {};

  test[TO_STRING_TAG$1] = 'z';

  // `Object.prototype.toString` method implementation
  // https://tc39.github.io/ecma262/#sec-object.prototype.tostring
  var objectToString = String(test) !== '[object z]' ? function toString() {
    return '[object ' + classof(this) + ']';
  } : test.toString;

  var ObjectPrototype = Object.prototype;

  // `Object.prototype.toString` method
  // https://tc39.github.io/ecma262/#sec-object.prototype.tostring
  if (objectToString !== ObjectPrototype.toString) {
    redefine(ObjectPrototype, 'toString', objectToString, { unsafe: true });
  }

  var TO_STRING = 'toString';
  var nativeToString = /./[TO_STRING];

  var NOT_GENERIC = fails(function () { return nativeToString.call({ source: 'a', flags: 'b' }) != '/a/b'; });
  // FF44- RegExp#toString has a wrong name
  var INCORRECT_NAME = nativeToString.name != TO_STRING;

  // `RegExp.prototype.toString` method
  // https://tc39.github.io/ecma262/#sec-regexp.prototype.tostring
  if (NOT_GENERIC || INCORRECT_NAME) {
    redefine(RegExp.prototype, TO_STRING, function toString() {
      var R = anObject(this);
      return '/'.concat(R.source, '/',
        'flags' in R ? R.flags : !descriptors && R instanceof RegExp ? regexpFlags.call(R) : undefined);
    }, { unsafe: true });
  }

  var oP = Object.prototype;
  /**
   * 是否对象
   * @param {any} o 判断变量
   * @return {boolean} 结构
   */

  function isObject$1(o) {
    return oP.toString.call(o) === '[object Object]';
  }
  /**
   * 是否string
   * @param {*} o
   */

  function isString(o) {
    return typeof o === 'string';
  }

  // @@match logic
  fixRegexpWellKnownSymbolLogic(
    'match',
    1,
    function (MATCH, nativeMatch, maybeCallNative) {
      return [
        // `String.prototype.match` method
        // https://tc39.github.io/ecma262/#sec-string.prototype.match
        function match(regexp) {
          var O = requireObjectCoercible(this);
          var matcher = regexp == undefined ? undefined : regexp[MATCH];
          return matcher !== undefined ? matcher.call(regexp, O) : new RegExp(regexp)[MATCH](String(O));
        },
        // `RegExp.prototype[@@match]` method
        // https://tc39.github.io/ecma262/#sec-regexp.prototype-@@match
        function (regexp) {
          var res = maybeCallNative(nativeMatch, regexp, this);
          if (res.done) return res.value;

          var rx = anObject(regexp);
          var S = String(this);

          if (!rx.global) return regexpExecAbstract(rx, S);

          var fullUnicode = rx.unicode;
          rx.lastIndex = 0;
          var A = [];
          var n = 0;
          var result;
          while ((result = regexpExecAbstract(rx, S)) !== null) {
            var matchStr = String(result[0]);
            A[n] = matchStr;
            if (matchStr === '') rx.lastIndex = advanceStringIndex(S, toLength(rx.lastIndex), fullUnicode);
            n++;
          }
          return n === 0 ? null : A;
        }
      ];
    }
  );

  /**
   * 获得文本块最后一行，并移除
   * @parma {array<object>} 文本块
   * @return {array<object>} 最后一行
   */

  function helperGetLastLIne(textList) {
    var results = [];

    for (var i = textList.length - 1; i >= 0; i--) {
      var inlineText = textList[i].content;
      var match = inlineText.match(/\n(.*?)$/);

      if (match) {
        var matched = match[1],
            index = match.index; // 后置文本清理

        textList[i].content = inlineText.substr(0, index);
        results.push(Object.assign({}, textList[i], {
          content: matched
        }));
        break;
      } else {
        results.push(textList[i]); // 清理textList末尾

        textList.pop();
      }
    }

    return results.reverse();
  }
  /**
   * 事件绑定
   * @param {HTMLElement} el 绑定dom
   * @param {string} event 事件名
   * @param {function} func 回调函数
   * @return {function} 解绑函数
   */

  function addEvent(el, event, func) {
    var callback = function callback(e) {
      return func(e);
    };

    el.addEventListener(event, callback);
    return function () {
      return el.removeEventListener(event, callback);
    };
  }

  var EMOJIMAP = {
  	"[仰慕]": {
  	path: "baozi/emjoy-仰慕.png",
  	url: "https://img.guihuazhi.com/image/hz/be/b8/beb847c8e54dbec49b9b5338d7c1d734v64x64.png",
  	size: 5630,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[无辜]": {
  	path: "baozi/emjoy-无辜.png",
  	url: "https://img.guihuazhi.com/image/hz/70/39/7039531f0bffbf4b1d3d624c66582384v64x64.png",
  	size: 5060,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[很尴尬]": {
  	path: "baozi/emjoy-尴尬.png",
  	url: "https://img.guihuazhi.com/image/hz/10/72/1072373c470e4595dc731d0d4e5c6b0dv64x64.png",
  	size: 4366,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[拍桌子]": {
  	path: "baozi/emjoy-拍桌子.png",
  	url: "https://img.guihuazhi.com/image/hz/7e/97/7e97bf7d6c338a7f873e7102cc328d22v64x64.png",
  	size: 4414,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[砸]": {
  	path: "baozi/emjoy-砸.png",
  	url: "https://img.guihuazhi.com/image/hz/64/15/64152abbd09f2b2de9e260711d2e22bdv64x64.png",
  	size: 4341,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[伸舌头]": {
  	path: "baozi/emjoy-伸舌头.png",
  	url: "https://img.guihuazhi.com/image/hz/ca/ac/caacc0be3e3b9289df95302b71d2dbd6v64x64.png",
  	size: 4417,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[老大]": {
  	path: "baozi/emjoy-老大.png",
  	url: "https://img.guihuazhi.com/image/hz/6f/6f/6f6f4ce92111f4e70567aac629baf259v64x64.png",
  	size: 4580,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[寒]": {
  	path: "baozi/emjoy-寒.png",
  	url: "https://img.guihuazhi.com/image/hz/e4/85/e4852abf339c746cda85f2472d61a64dv64x64.png",
  	size: 5235,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[哭]": {
  	path: "baozi/emjoy-哭.png",
  	url: "https://img.guihuazhi.com/image/hz/12/0a/120a0b976fadb97d38e8f5563e5a9774v64x64.png",
  	size: 4666,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[伤心]": {
  	path: "baozi/emjoy-伤心.png",
  	url: "https://img.guihuazhi.com/image/hz/57/a9/57a93a97b24d63216a077094936b4a91v64x64.png",
  	size: 4873,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[很得意]": {
  	path: "baozi/emjoy-得意.png",
  	url: "https://img.guihuazhi.com/image/hz/a0/71/a07163f8f7a7209cf63a6977ae6f4391v64x64.png",
  	size: 4284,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[恐怖]": {
  	path: "baozi/emjoy-恐怖.png",
  	url: "https://img.guihuazhi.com/image/hz/9a/f2/9af270856b4eb517baf5a0e46cc42c4bv64x64.png",
  	size: 5315,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[哭泣]": {
  	path: "baozi/emjoy-大哭.png",
  	url: "https://img.guihuazhi.com/image/hz/44/a3/44a341f00d3fd5d186b3b39e57a76c75v64x64.png",
  	size: 5291,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[激动]": {
  	path: "baozi/emjoy-激动.png",
  	url: "https://img.guihuazhi.com/image/hz/8a/fe/8afe8eedb5121214fffb4d0f7176dbadv64x64.png",
  	size: 4847,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[赞]": {
  	path: "baozi/emjoy-赞.png",
  	url: "https://img.guihuazhi.com/image/hz/c9/29/c92900946a1294a5bbef065477ccb4a5v64x64.png",
  	size: 5606,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[唱歌]": {
  	path: "baozi/emjoy-唱歌.png",
  	url: "https://img.guihuazhi.com/image/hz/89/f3/89f3573aa24b4986b30ac7da47578cf1v64x64.png",
  	size: 4326,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[害羞]": {
  	path: "baozi/emjoy-害羞.png",
  	url: "https://img.guihuazhi.com/image/hz/7b/a4/7ba46a63994991bb4bc0ad52e7bd72edv64x64.png",
  	size: 5374,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[脸红]": {
  	path: "baozi/emjoy-脸红.png",
  	url: "https://img.guihuazhi.com/image/hz/75/26/7526ae1a305c1b07703f495eca264d6dv64x64.png",
  	size: 4326,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[微笑]": {
  	path: "baozi/emjoy-微笑.png",
  	url: "https://img.guihuazhi.com/image/hz/ff/51/ff51e1843d77e9c49b2cc2b5c6ab9921v64x64.png",
  	size: 4043,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[好可怜]": {
  	path: "baozi/emjoy-可怜.png",
  	url: "https://img.guihuazhi.com/image/hz/7a/dd/7add2c28e54047e8120c50ba20b44090v64x64.png",
  	size: 5777,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[酷酷的]": {
  	path: "baozi/emjoy-酷.png",
  	url: "https://img.guihuazhi.com/image/hz/be/56/be56121eecc3fa3ff3306125b643c308v64x64.png",
  	size: 4436,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[心碎]": {
  	path: "baozi/emjoy-心碎.png",
  	url: "https://img.guihuazhi.com/image/hz/ae/a3/aea3ca62cb19b02ba228de04b06c0d69v64x64.png",
  	size: 3600,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[很惊讶]": {
  	path: "baozi/emjoy-惊讶.png",
  	url: "https://img.guihuazhi.com/image/hz/86/58/86581676dfd2a7196d6bbfade1f1e5d4v64x64.png",
  	size: 5028,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[气愤]": {
  	path: "baozi/emjoy-气愤.png",
  	url: "https://img.guihuazhi.com/image/hz/aa/7d/aa7dd0514f09d51667219087fc0f5992v64x64.png",
  	size: 5199,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[喊话]": {
  	path: "baozi/emjoy-喊话.png",
  	url: "https://img.guihuazhi.com/image/hz/83/a2/83a208392933b0db34981b0f9dc16575v64x64.png",
  	size: 4506,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[握手]": {
  	path: "baozi/emjoy-握手.png",
  	url: "https://img.guihuazhi.com/image/hz/7e/4e/7e4ecba2ea1822df06e37c2e852412cfv64x64.png",
  	size: 3580,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[撒娇]": {
  	path: "baozi/emjoy-撒娇.png",
  	url: "https://img.guihuazhi.com/image/hz/f1/67/f1676a269584a45342fca2a9b099e8f6v64x64.png",
  	size: 4830,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[晕了]": {
  	path: "baozi/emjoy-晕了.png",
  	url: "https://img.guihuazhi.com/image/hz/e7/ae/e7ae71b1bfb43ab3a23409e2cf7904bev64x64.png",
  	size: 5286,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[惊吓]": {
  	path: "baozi/emjoy-惊吓.png",
  	url: "https://img.guihuazhi.com/image/hz/f3/75/f3759ebf2c0057f729e35a0a6461fb78v64x64.png",
  	size: 4756,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[汗]": {
  	path: "baozi/emjoy-汗.png",
  	url: "https://img.guihuazhi.com/image/hz/82/4b/824b80638f072cd16c769f82543df32av64x64.png",
  	size: 4739,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[流口水]": {
  	path: "baozi/emjoy-流口水.png",
  	url: "https://img.guihuazhi.com/image/hz/ed/89/ed89ac58ffc8a161d489aba283d2d528v64x64.png",
  	size: 5049,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[鼻血]": {
  	path: "baozi/emjoy-鼻血.png",
  	url: "https://img.guihuazhi.com/image/hz/60/7f/607fe2826d650cd489b7a50c966d8742v64x64.png",
  	size: 4970,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[喜欢]": {
  	path: "baozi/emjoy-喜欢.png",
  	url: "https://img.guihuazhi.com/image/hz/bb/6b/bb6b1b7996d28d4da396b1c16ae8301bv64x64.png",
  	size: 4806,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[邪恶]": {
  	path: "baozi/emjoy-邪恶.png",
  	url: "https://img.guihuazhi.com/image/hz/35/ba/35ba542143382619426a8f8ddb171066v64x64.png",
  	size: 3832,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[啵]": {
  	path: "baozi/emjoy-啵.png",
  	url: "https://img.guihuazhi.com/image/hz/78/3c/783cb7bfa01e307d7b15dbbc90935810v64x64.png",
  	size: 4795,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[望]": {
  	path: "baozi/emjoy-望.png",
  	url: "https://img.guihuazhi.com/image/hz/73/24/7324a37bc01af2c6dd10fbb0d1c71f8bv64x64.png",
  	size: 4336,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[鲜花]": {
  	path: "baozi/emjoy-鲜花.png",
  	url: "https://img.guihuazhi.com/image/hz/b6/15/b61511a3a54294493221244af6aee259v64x64.png",
  	size: 3851,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[招呼]": {
  	path: "baozi/emjoy-招呼.png",
  	url: "https://img.guihuazhi.com/image/hz/65/e3/65e36b358ab7da9dae5d33830be5f8c0v64x64.png",
  	size: 4926,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[心跳]": {
  	path: "baozi/emjoy-心跳.png",
  	url: "https://img.guihuazhi.com/image/hz/dd/9a/dd9a2aed589dcf23150e91fd3aef0266v64x64.png",
  	size: 2621,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[YEAH]": {
  	path: "baozi/emjoy-YEAH.png",
  	url: "https://img.guihuazhi.com/image/hz/62/89/62895cb504e98777570512624f0af4a1v64x64.png",
  	size: 4643,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[色眯眯]": {
  	path: "baozi/emjoy-色眯眯.png",
  	url: "https://img.guihuazhi.com/image/hz/48/45/4845befe545d23876f63e58337c8d247v64x64.png",
  	size: 5094,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[委屈]": {
  	path: "baozi/emjoy-委屈.png",
  	url: "https://img.guihuazhi.com/image/hz/54/dd/54ddeafc73887aae0e57b5632a7c657ev64x64.png",
  	size: 5216,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[眨眼]": {
  	path: "baozi/emjoy-眨眼.png",
  	url: "https://img.guihuazhi.com/image/hz/c7/3d/c73d26c5288c9e8892b5b99f9c569d6ev64x64.png",
  	size: 4870,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[超人]": {
  	path: "baozi/emjoy-超人.png",
  	url: "https://img.guihuazhi.com/image/hz/d6/30/d630613c6d04cc96fe69deb1cfdc9dfbv64x64.png",
  	size: 6140,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[无语]": {
  	path: "baozi/emjoy-无语.png",
  	url: "https://img.guihuazhi.com/image/hz/1c/e8/1ce8040edaa53cf62125992dfb4f809av64x64.png",
  	size: 4595,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[亲]": {
  	path: "baozi/emjoy-亲.png",
  	url: "https://img.guihuazhi.com/image/hz/8c/d2/8cd2afab975c05d3f3032edebd51bbecv64x64.png",
  	size: 4212,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[送花]": {
  	path: "baozi/emjoy-送花.png",
  	url: "https://img.guihuazhi.com/image/hz/26/a7/26a72e449320a256da34208fcc22b8c9v64x64.png",
  	size: 4979,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[鄙视你]": {
  	path: "baozi/emjoy-鄙视.png",
  	url: "https://img.guihuazhi.com/image/hz/5b/39/5b398b001f3a04f08c981b85c8f0656cv64x64.png",
  	size: 4681,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[敲死你]": {
  	path: "baozi/emjoy-敲死你.png",
  	url: "https://img.guihuazhi.com/image/hz/e5/cc/e5cc14f7a9f4541bde668bb464504004v64x64.png",
  	size: 5008,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[飞吻]": {
  	path: "baozi/emjoy-飞吻.png",
  	url: "https://img.guihuazhi.com/image/hz/27/11/27118e2567041c571d2cd1e172973cc7v64x64.png",
  	size: 5297,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[好棒]": {
  	path: "baozi/emjoy-好棒.png",
  	url: "https://img.guihuazhi.com/image/hz/40/70/4070f5751ad5b0f08ffe6486ba417032v64x64.png",
  	size: 4715,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[擦汗]": {
  	path: "baozi/emjoy-擦汗.png",
  	url: "https://img.guihuazhi.com/image/hz/3b/e8/3be8fcc14aa0233d43d9783ab961ee61v64x64.png",
  	size: 4743,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[笑]": {
  	path: "baozi/emjoy-笑.png",
  	url: "https://img.guihuazhi.com/image/hz/c6/20/c620f03514d2c8c05e20417e0e9087abv64x64.png",
  	size: 4827,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[白眼你]": {
  	path: "baozi/emjoy-白眼.png",
  	url: "https://img.guihuazhi.com/image/hz/06/2a/062a5f697e6beca419411f5f09d89758v64x64.png",
  	size: 4302,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[睡着]": {
  	path: "baozi/emjoy-睡着.png",
  	url: "https://img.guihuazhi.com/image/hz/7f/be/7fbe368bc47e21776a2d6df8e4068098v64x64.png",
  	size: 4960,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[不要]": {
  	path: "baozi/emjoy-不要.png",
  	url: "https://img.guihuazhi.com/image/hz/80/1c/801c3e81183c35bfc422e81840ac1ecav64x64.png",
  	size: 4895,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[震惊]": {
  	path: "baozi/emjoy-震惊.png",
  	url: "https://img.guihuazhi.com/image/hz/e6/83/e6831e8d17570632b0ac8378b5eec126v64x64.png",
  	size: 4719,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[你闭嘴]": {
  	path: "baozi/emjoy-闭嘴.png",
  	url: "https://img.guihuazhi.com/image/hz/6a/bc/6abcf5968d2071449c6badc10e985c97v64x64.png",
  	size: 5114,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[很开心]": {
  	path: "baozi/emjoy-开心.png",
  	url: "https://img.guihuazhi.com/image/hz/49/78/49789caaab6d77bbfade89c36bdf035dv64x64.png",
  	size: 4645,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[找死]": {
  	path: "baozi/emjoy-找死.png",
  	url: "https://img.guihuazhi.com/image/hz/32/93/3293d2021375bce4c8e5396b4389e18ev64x64.png",
  	size: 5042,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[吆喝]": {
  	path: "baozi/emjoy-吆喝.png",
  	url: "https://img.guihuazhi.com/image/hz/ef/70/ef704a7456b786926c0e05363bf55f3dv64x64.png",
  	size: 4920,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[恩恩]": {
  	path: "baozi/emjoy-恩恩.png",
  	url: "https://img.guihuazhi.com/image/hz/1b/89/1b89ea4f8b80b5e833dc3d10248d64fbv64x64.png",
  	size: 4441,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[偷笑]": {
  	path: "baozi/emjoy-偷笑.png",
  	url: "https://img.guihuazhi.com/image/hz/71/6c/716c8524441c7f86d47f2dda9cbb9326v64x64.png",
  	size: 4664,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[嘿嘿]": {
  	path: "baozi/emjoy-嘿嘿.png",
  	url: "https://img.guihuazhi.com/image/hz/93/91/9391104836222ea5cbdb1fa1788da78fv64x64.png",
  	size: 5491,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[凶]": {
  	path: "baozi/emjoy-凶.png",
  	url: "https://img.guihuazhi.com/image/hz/77/61/7761acca1c11288106b39c747f4d2b96v64x64.png",
  	size: 4791,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[色色地]": {
  	path: "baozi/emjoy-色色地.png",
  	url: "https://img.guihuazhi.com/image/hz/4a/22/4a22c81918e7c6ff94d7025f20f074e8v64x64.png",
  	size: 5505,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[呼噜]": {
  	path: "baozi/emjoy-呼噜.png",
  	url: "https://img.guihuazhi.com/image/hz/93/a7/93a7e0afa57e46b72332b5d1dd4dc672v64x64.png",
  	size: 4393,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[挑衅]": {
  	path: "baozi/emjoy-挑衅.png",
  	url: "https://img.guihuazhi.com/image/hz/5e/ca/5eca8ce7a7a7d8803ce37ab27c72e8c7v64x64.png",
  	size: 4844,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[自转]": {
  	path: "baozi/emjoy-自转.png",
  	url: "https://img.guihuazhi.com/image/hz/3e/dd/3edd58fe54f1b1be9d74504818e74be8v64x64.png",
  	size: 4255,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[猪]": {
  	path: "baozi/emjoy-猪.png",
  	url: "https://img.guihuazhi.com/image/hz/b0/46/b046909cdd98f2e5fe018dff5a88b555v64x64.png",
  	size: 5309,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[困了]": {
  	path: "baozi/emjoy-困.png",
  	url: "https://img.guihuazhi.com/image/hz/f2/d2/f2d287b2c60984486429b716c5ebf1c8v64x64.png",
  	size: 5342,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[骂]": {
  	path: "baozi/emjoy-骂.png",
  	url: "https://img.guihuazhi.com/image/hz/07/10/07108da97afa2270cba0d7601c378c90v64x64.png",
  	size: 5196,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[不行]": {
  	path: "baozi/emjoy-不行.png",
  	url: "https://img.guihuazhi.com/image/hz/4a/d3/4ad3961fb0f3fd5717c8c134c1872336v64x64.png",
  	size: 4388,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[鼓掌]": {
  	path: "baozi/emjoy-鼓掌.png",
  	url: "https://img.guihuazhi.com/image/hz/5c/7c/5c7cc145f650389fe87f44db2df68aeev64x64.png",
  	size: 4776,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[挖鼻孔]": {
  	path: "baozi/emjoy-挖鼻孔.png",
  	url: "https://img.guihuazhi.com/image/hz/59/a0/59a08ddfea1f8d9a50bdbd0892256abev64x64.png",
  	size: 4532,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[问号]": {
  	path: "baozi/emjoy-问号.png",
  	url: "https://img.guihuazhi.com/image/hz/93/0c/930c4ffd65c70ccd1170d54168b3c345v64x64.png",
  	size: 5442,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[翻滚]": {
  	path: "baozi/emjoy-翻滚.png",
  	url: "https://img.guihuazhi.com/image/hz/99/55/99550b55b88603da86b91bd92afdef6bv64x64.png",
  	size: 4404,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[红牌]": {
  	path: "baozi/emjoy-红牌.png",
  	url: "https://img.guihuazhi.com/image/hz/8d/9c/8d9cad073bf6e0fbed169099a1c28566v64x64.png",
  	size: 4390,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[哭闹]": {
  	path: "baozi/emjoy-哭闹.png",
  	url: "https://img.guihuazhi.com/image/hz/47/6b/476b73654b30b2a8cb9ea796287deb0av64x64.png",
  	size: 5479,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[路过]": {
  	path: "baozi/emjoy-路过.png",
  	url: "https://img.guihuazhi.com/image/hz/0e/b3/0eb350c7b1bddc516fc3e3b750047bc0v64x64.png",
  	size: 5660,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[怒吼]": {
  	path: "baozi/emjoy-怒吼.png",
  	url: "https://img.guihuazhi.com/image/hz/1f/53/1f53c920f7e8e6129aa9432aa5f926e3v64x64.png",
  	size: 5396,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[嘲笑]": {
  	path: "baozi/emjoy-嘲笑.png",
  	url: "https://img.guihuazhi.com/image/hz/9a/7b/9a7b09f98ef03b62bca4d416c9d3ddfev64x64.png",
  	size: 5429,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[飘过]": {
  	path: "baozi/emjoy-飘过.png",
  	url: "https://img.guihuazhi.com/image/hz/d0/63/d0631ab1b36b4f182d06093f9dfb582bv64x64.png",
  	size: 4668,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[扇扇子]": {
  	path: "baozi/emjoy-扇扇子.png",
  	url: "https://img.guihuazhi.com/image/hz/5f/29/5f299c9d356e090898ce08116c7a4544v64x64.png",
  	size: 5340,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[狂暴]": {
  	path: "baozi/emjoy-狂暴.png",
  	url: "https://img.guihuazhi.com/image/hz/19/b1/19b19674d569dbe681a3975245b3047fv64x64.png",
  	size: 5834,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[拽]": {
  	path: "baozi/emjoy-拽.png",
  	url: "https://img.guihuazhi.com/image/hz/af/e6/afe6b79595f1a44fcb6a8f36809d0f45v64x64.png",
  	size: 4842,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[真爱]": {
  	path: "baozi/emjoy-真爱.png",
  	url: "https://img.guihuazhi.com/image/hz/9f/75/9f757c37b05ac6999a397c36f2ffe446v64x64.png",
  	size: 4942,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[亮瞎]": {
  	path: "baozi/emjoy-亮瞎.png",
  	url: "https://img.guihuazhi.com/image/hz/91/79/917982eaab84c5681196b97a1a14ff78v64x64.png",
  	size: 4312,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[吐]": {
  	path: "baozi/emjoy-吐.png",
  	url: "https://img.guihuazhi.com/image/hz/4c/12/4c12f13b64ce04c0d2501b119c2b5076v64x64.png",
  	size: 4634,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[拍拍头]": {
  	path: "baozi/emjoy-拍拍头.png",
  	url: "https://img.guihuazhi.com/image/hz/d3/f7/d3f711bff015f336f2fe731c8ff4a3d7v64x64.png",
  	size: 5684,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[很愤怒]": {
  	path: "baozi/emjoy-愤怒.png",
  	url: "https://img.guihuazhi.com/image/hz/f5/bd/f5bd9bf217272c8cdc63a9d8b7b92168v64x64.png",
  	size: 4724,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[不屑]": {
  	path: "baozi/emjoy-不屑.png",
  	url: "https://img.guihuazhi.com/image/hz/21/b6/21b616be233ead2c7fa4630bc6d59534v64x64.png",
  	size: 4489,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[思考]": {
  	path: "baozi/emjoy-思考.png",
  	url: "https://img.guihuazhi.com/image/hz/da/f0/daf01c4ffc8c097c351d9257992a065fv64x64.png",
  	size: 5280,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[吃萝卜]": {
  	path: "baozi/emjoy-吃萝卜.png",
  	url: "https://img.guihuazhi.com/image/hz/88/b8/88b805601afc3b6cf848c9a3f2ed6ac2v64x64.png",
  	size: 5483,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[领悟]": {
  	path: "baozi/emjoy-领悟.png",
  	url: "https://img.guihuazhi.com/image/hz/db/9c/db9c0fb724a51b45ca50a30e0a5aceb2v64x64.png",
  	size: 5163,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[不好意思]": {
  	path: "baozi/emjoy-不好意思.png",
  	url: "https://img.guihuazhi.com/image/hz/0d/80/0d809d00308faf23430dfbde83b150cev64x64.png",
  	size: 4845,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[平常心]": {
  	path: "face/emjoy-平常心.png",
  	url: "https://img.guihuazhi.com/image/hz/8c/a5/8ca59a7a58427bc539fc80b12b258c97v64x64.png",
  	size: 5169,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[无趣]": {
  	path: "face/emjoy-无趣.png",
  	url: "https://img.guihuazhi.com/image/hz/e0/d9/e0d9296d0b98e3609612fde62992dc88v64x64.png",
  	size: 5265,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[色]": {
  	path: "face/emjoy-色.png",
  	url: "https://img.guihuazhi.com/image/hz/7a/8c/7a8c7d606cc04871b3902aac704b4e53v64x64.png",
  	size: 6612,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[酷]": {
  	path: "face/emjoy-酷.png",
  	url: "https://img.guihuazhi.com/image/hz/a3/1b/a31bf3fb6a18467844a749f2191eb347v64x64.png",
  	size: 5259,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[发呆]": {
  	path: "face/emjoy-发呆.png",
  	url: "https://img.guihuazhi.com/image/hz/df/ef/dfef50f2db2df97a9d4fcfd5e182cd25v64x64.png",
  	size: 5559,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[流泪]": {
  	path: "face/emjoy-流泪.png",
  	url: "https://img.guihuazhi.com/image/hz/eb/34/eb349d6d71ec644f38e99715f2bdf1f8v64x64.png",
  	size: 5594,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[坏笑]": {
  	path: "face/emjoy-坏笑.png",
  	url: "https://img.guihuazhi.com/image/hz/2a/0a/2a0a0eb3827fa5366b7989d11e768c1cv64x64.png",
  	size: 5267,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[别理我]": {
  	path: "face/emjoy-别理我.png",
  	url: "https://img.guihuazhi.com/image/hz/e7/7a/e77ade1ed275f5d1d225def2f52c7ea5v64x64.png",
  	size: 5359,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[鄙视]": {
  	path: "face/emjoy-鄙视.png",
  	url: "https://img.guihuazhi.com/image/hz/fb/c0/fbc08fb69773ad29bc7c11bc86cb16f6v64x64.png",
  	size: 5499,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[白眼]": {
  	path: "face/emjoy-白眼.png",
  	url: "https://img.guihuazhi.com/image/hz/3a/7d/3a7dbb8d7e84ef0e95c81ce75edfd728v64x64.png",
  	size: 5352,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[糗大了]": {
  	path: "face/emjoy-糗大了.png",
  	url: "https://img.guihuazhi.com/image/hz/8c/e7/8ce7dc9570d687f6fc5c94e249057e02v64x64.png",
  	size: 5893,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[愤怒]": {
  	path: "face/emjoy-愤怒.png",
  	url: "https://img.guihuazhi.com/image/hz/88/c5/88c52cadd197b0d3c4d78575b66aecacv64x64.png",
  	size: 5892,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[开心]": {
  	path: "face/emjoy-开心.png",
  	url: "https://img.guihuazhi.com/image/hz/16/78/1678448ce7c7a888cccdc174b2af1904v64x64.png",
  	size: 5223,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[抠鼻]": {
  	path: "face/emjoy-抠鼻.png",
  	url: "https://img.guihuazhi.com/image/hz/d9/4b/d94b15fcd0b656d8215e7838456e2dc5v64x64.png",
  	size: 5974,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[惊恐]": {
  	path: "face/emjoy-惊恐.png",
  	url: "https://img.guihuazhi.com/image/hz/f6/02/f6020c7607143e0926b12d9cd5b37c10v64x64.png",
  	size: 5820,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[石化]": {
  	path: "face/emjoy-石化.png",
  	url: "https://img.guihuazhi.com/image/hz/60/aa/60aa69303a9f074fb057c456447a8fa3v64x64.png",
  	size: 4659,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[叹气]": {
  	path: "face/emjoy-叹气.png",
  	url: "https://img.guihuazhi.com/image/hz/82/cb/82cbc293f830d5aaa72796c468a3679av64x64.png",
  	size: 5876,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[衰]": {
  	path: "face/emjoy-衰.png",
  	url: "https://img.guihuazhi.com/image/hz/dc/96/dc965db3071274c0c1d567a322676deav64x64.png",
  	size: 5551,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[疑问]": {
  	path: "face/emjoy-疑问.png",
  	url: "https://img.guihuazhi.com/image/hz/f5/a6/f5a6b9b3b5102104562c9887e2d28374v64x64.png",
  	size: 5778,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[兴奋]": {
  	path: "face/emjoy-兴奋.png",
  	url: "https://img.guihuazhi.com/image/hz/7b/e3/7be3cf9927f962ee9f596d00d48ddee2v64x64.png",
  	size: 6223,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[傲慢]": {
  	path: "face/emjoy-傲慢.png",
  	url: "https://img.guihuazhi.com/image/hz/d5/22/d5223164691db6d3e7dc03007e84f282v64x64.png",
  	size: 5653,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[得意]": {
  	path: "face/emjoy-得意.png",
  	url: "https://img.guihuazhi.com/image/hz/55/f1/55f145cf742908ccb670b7aeae8c7cfdv64x64.png",
  	size: 6549,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[冷汗]": {
  	path: "face/emjoy-冷汗.png",
  	url: "https://img.guihuazhi.com/image/hz/5f/1a/5f1aa8089421458c0873805dec747255v64x64.png",
  	size: 5767,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[天使]": {
  	path: "face/emjoy-天使.png",
  	url: "https://img.guihuazhi.com/image/hz/92/cc/92cc1af0df03eb287f891f207c4b1396v64x64.png",
  	size: 6304,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[大哭]": {
  	path: "face/emjoy-大哭.png",
  	url: "https://img.guihuazhi.com/image/hz/7e/72/7e72b376fdc5ac4fcee2af225c1a0b9fv64x64.png",
  	size: 6575,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[打脸]": {
  	path: "face/emjoy-打脸.png",
  	url: "https://img.guihuazhi.com/image/hz/ae/ab/aeab96044342108d821e98aadb2956ebv64x64.png",
  	size: 6279,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[敬佩]": {
  	path: "face/emjoy-敬佩.png",
  	url: "https://img.guihuazhi.com/image/hz/58/a2/58a24c0fe38ae7143bb04e10c9929793v64x64.png",
  	size: 6444,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[咒骂]": {
  	path: "face/emjoy-咒骂.png",
  	url: "https://img.guihuazhi.com/image/hz/7f/87/7f87183a0e4a9af49f5cbd3cbe87e8eev64x64.png",
  	size: 6546,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[嘘]": {
  	path: "face/emjoy-嘘.png",
  	url: "https://img.guihuazhi.com/image/hz/d9/ff/d9ff83b65797aa08d0d51f4bee985e25v64x64.png",
  	size: 6100,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[冲]": {
  	path: "face/emjoy-冲.png",
  	url: "https://img.guihuazhi.com/image/hz/9b/1d/9b1d95f25c257af5f0e0f6ee5c8dd8fbv64x64.png",
  	size: 6444,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[尴尬]": {
  	path: "face/emjoy-尴尬.png",
  	url: "https://img.guihuazhi.com/image/hz/61/d3/61d3da3918898932dcc435c9b1d3083av64x64.png",
  	size: 5847,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[伤不起]": {
  	path: "face/emjoy-伤不起.png",
  	url: "https://img.guihuazhi.com/image/hz/29/89/2989e7e4d558cd763c85d995aa8c0bd7v64x64.png",
  	size: 6350,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[撇嘴]": {
  	path: "face/emjoy-撇嘴.png",
  	url: "https://img.guihuazhi.com/image/hz/62/db/62db4738d5a54028a382f44e8a132b00v64x64.png",
  	size: 5911,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[憨笑]": {
  	path: "face/emjoy-憨笑.png",
  	url: "https://img.guihuazhi.com/image/hz/23/cb/23cb04762579f9913f0183be5b5cc5d7v64x64.png",
  	size: 5467,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[难过]": {
  	path: "face/emjoy-难过.png",
  	url: "https://img.guihuazhi.com/image/hz/6b/d6/6bd6673be270329d309b31b5e39b2c35v64x64.png",
  	size: 5764,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[困]": {
  	path: "face/emjoy-困.png",
  	url: "https://img.guihuazhi.com/image/hz/c4/67/c467ca3d60a10d55b13026c49ba86d7bv64x64.png",
  	size: 5387,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[调皮]": {
  	path: "face/emjoy-调皮.png",
  	url: "https://img.guihuazhi.com/image/hz/19/a8/19a80696bf7c68a9c95aa3990c0177f6v64x64.png",
  	size: 6517,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[奋斗]": {
  	path: "face/emjoy-奋斗.png",
  	url: "https://img.guihuazhi.com/image/hz/bb/d2/bbd21c056a793a1d9365d0192d26be36v64x64.png",
  	size: 6832,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[再见]": {
  	path: "face/emjoy-再见.png",
  	url: "https://img.guihuazhi.com/image/hz/34/54/3454379bb9658cf9b319d567e133bbaev64x64.png",
  	size: 5702,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[可怜]": {
  	path: "face/emjoy-可怜.png",
  	url: "https://img.guihuazhi.com/image/hz/e6/7c/e67c01fe0363c81e00b24d13efb88337v64x64.png",
  	size: 6174,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[折磨]": {
  	path: "face/emjoy-折磨.png",
  	url: "https://img.guihuazhi.com/image/hz/56/92/5692711958868348b47138dfd1b0883ev64x64.png",
  	size: 6439,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[闭嘴]": {
  	path: "face/emjoy-闭嘴.png",
  	url: "https://img.guihuazhi.com/image/hz/e4/7f/e47fb51a6158cf9cb69c4cabbda39ecfv64x64.png",
  	size: 5845,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[恶心]": {
  	path: "face/emjoy-恶心.png",
  	url: "https://img.guihuazhi.com/image/hz/e0/d2/e0d23ce71c4de57f8d05e2f0bf42a632v64x64.png",
  	size: 5220,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[快哭了]": {
  	path: "face/emjoy-快哭了.png",
  	url: "https://img.guihuazhi.com/image/hz/d4/7c/d47ce311e43b3783c4760d889e57f8dfv64x64.png",
  	size: 5812,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[晕]": {
  	path: "face/emjoy-晕.png",
  	url: "https://img.guihuazhi.com/image/hz/f4/4d/f44d222f7efa39156bd4b1393e0a6244v64x64.png",
  	size: 6848,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[砸头]": {
  	path: "face/emjoy-砸头.png",
  	url: "https://img.guihuazhi.com/image/hz/ea/16/ea16caf9f766961ace3480eb1a919d66v64x64.png",
  	size: 6106,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[求带]": {
  	path: "face/emjoy-求带.png",
  	url: "https://img.guihuazhi.com/image/hz/44/b8/44b8c0218b74f1097b807dc8675d4e1bv64x64.png",
  	size: 6194,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[惊讶]": {
  	path: "face/emjoy-惊讶.png",
  	url: "https://img.guihuazhi.com/image/hz/e0/08/e008246dedfe9cab397930193fb14dc4v64x64.png",
  	size: 5624,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  },
  	"[睡觉]": {
  	path: "face/emjoy-睡觉.png",
  	url: "https://img.guihuazhi.com/image/hz/72/50/7250644d613fdf7a2eaecc72f4014527v64x64.png",
  	size: 5526,
  	extra: {
  		format: "png",
  		width: 64,
  		height: 64
  	}
  }
  };

  /**
   * @type {boolean} 是否开发环境
   */

  var isDev = false;
  /**
   * @type {boolean} 是是否服务端渲染
   */

  var isSSR = false;

  try {
    isDev = process.env && process.env.NODE_ENV === 'development';
    isSSR = process.env && process.env.VUE_ENV === 'server';
  } catch (e) {} //

  /**
   * @type {Regexp} 判断是否合法图片
   */


  var validImageRegexp = /^(http|https):\/\/(imgtest|img)\.guihuazhi\.com\/[A-z0-9/.]*?$/;
  /**
   * @type {Regexp} 表情校验
   */

  var validEmoji = /(\[[\u4e00-\u9fa5]{1,4}\])/g;

  var Parse =
  /*#__PURE__*/
  function () {
    function Parse(option) {
      this.platform = option.platform;
    }

    var _proto = Parse.prototype;

    _proto.createElement = function createElement(d) {
      var _this = this;

      if (isObject$1(d)) {
        var tag = d.tag,
            _d$attrs = d.attrs,
            attrs = _d$attrs === void 0 ? {} : _d$attrs,
            _d$child = d.child,
            child = _d$child === void 0 ? [] : _d$child,
            props = d.props,
            content = d.content;
        var node = document.createElement(tag);
        Object.keys(attrs).forEach(function (key) {
          node.setAttribute(key, attrs[key]);
        });

        if (tag === 'img') {
          node = this.renderImageDom(props, attrs);
        }

        if (tag === 'a') {
          node = this.renderLinkDom(props);
        }

        if (content) {
          node.innerHTML = content;
        } else {
          child.forEach(function (c) {
            node.appendChild(_this.createElement(c));
          });
        }

        return node;
      } else if (typeof d === 'string') {
        return document.createTextNode(d);
      }
    };

    _proto.reset = function reset() {
      this.unbindImageEvents && this.unbindImageEvents();
    } // 懒加载图片
    ;

    _proto.bindImageLazyLoad = function bindImageLazyLoad() {
      var _this2 = this;

      this.clientHeight = window.screen.height;
      this.unbindImageEvents = addEvent(window, 'scroll', this.loadImageFunc.bind(this));
      setTimeout(function () {
        // 初始化时加载一次图片
        _this2.loadImageFunc();
      }, 0);
    } // 取消懒加载图片
    ;

    _proto.unbindImageLazyLoad = function unbindImageLazyLoad() {
      this.unbindImageEvents();
    };

    _proto.loadImageFunc = function loadImageFunc() {
      var _this3 = this;

      (this.imageDoc = this.imageDoc || document.querySelectorAll(".huazhi.huazhi-" + this.platform + " img")).forEach(function (el) {
        if (el.getAttribute('src')) return;
        var src = el.dataset.src;
        var o = el.getBoundingClientRect();

        if (o.top < _this3.clientHeight) {
          el.setAttribute('src', src);
          el.previousSibling.style.opacity = 0;
        }
      });
    }
    /**
     * dom-tree => html
     * @param {array<object>} tree
     */
    ;

    _proto.renderDomTreeHTML = function renderDomTreeHTML(tree, platform) {
      var _this4 = this;

      return tree.map(function (block) {
        switch (block.tag) {
          case 'h1':
            return "<h1>" + _this4.renderDomTreeHTML(block.child) + "</h1>";

          case 'blockquote':
            return "<blockquote>" + _this4.renderDomTreeHTML(block.child) + "</blockquote>";

          case 'p':
            return "<p>" + _this4.renderDomTreeHTML(block.child) + "</p>";

          case 'b':
            return "<b>" + block.content + "</b>";

          case 'i':
            return "<i style=\"background-image: url(" + block.props.url + ")\" emoji=\"" + block.props.emoji + "\"></i>";

          case 'img':
            return _this4.renderImage(block.props, block.attrs);

          case 'hr':
            return '<hr />';

          case 'a':
            return _this4.renderLink(block.props);
          // webview内禁止直接跳转

          default:
            // 非兼容格式不做显示
            return isString(block) ? block : '';
        }
      }).join('');
    } // replaceBlock(block) {
    //   return block.replace
    // }

    /**
     * 针对web的文本解析处理
     * @param {array<object>} json
     * @return
     */
    ;

    _proto.jsonToDomTree = function jsonToDomTree(json) {
      var results = [];
      var imageIndex = 0;

      if (typeof json === 'string') {
        try {
          json = JSON.parse(json);
        } catch (e) {
          //
          return results;
        }
      }

      for (var i = 0, l = json.length; i < l; i++) {
        var block = json[i];

        if (block.type === 'text') {
          var tag = void 0; // if (block.value && block.value[0].type === 'link') {
          //   results.push({
          //     tag: 'a',
          //     props: {
          //       ...block,
          //     }
          //   });
          // } else {
          //   if (block.head === 1) {
          //     tag = 'h1';
          //   } else if (block.block === 1) {
          //     tag = 'blockquote';
          //   } else {
          //     tag = 'p';
          //   }
          //   let child = this.parseInline(block.value);
          //   results.push({ tag, child });
          // }

          if (block.head === 1) {
            tag = 'h1';
          } else if (block.block === 1) {
            tag = 'blockquote';
          } else {
            tag = 'p';
          }

          var child = this.parseInline(block.value);
          results.push({
            tag: tag,
            child: child
          });
        } else if (block.type === 'image' && this.isImage(block)) {
          results.push({
            tag: 'img',
            attrs: {
              src: block.url,
              index: imageIndex++
            },
            props: block
          });
        } else if (block.type === 'line') {
          results.push({
            tag: 'hr'
          });
        } // else if (block.type === 'link') {
        //   let ext = {};
        //
        //   if (block.category === 'article') {
        //     let match = block.url.match(/(\d+)&/);
        //     let id = match && match[1];
        //     if (id) ext.id = id;
        //   }
        //   results.push({
        //     tag: 'a',
        //     props: {
        //       ...block,
        //       ...ext
        //     }
        //   });
        // }

      }

      return results;
    }
    /**
     * 评论中的文本解析
     * @param {string} str 评论文本
     * @return {string} html文本
     */
    ;

    _proto.parseComment = function parseComment(str) {
      var result = this.parseEmoji(str);
      var html = this.renderDomTreeHTML(result, this.platform);
      return html;
    }
    /**
     * json => html
     * @param  {string|array<object>} json 原始json数据 | 数组结构
     * @param {string} platform 平台 web | mobile | webview | editor
     * @param {HTMLElement} wrapperDom 是否返回document对象
     * @param {number} containerWidth 容器宽度
     * @return {string|HTMLElement} html字符串/document对象
     */
    ;

    _proto.jsonToHTML = function jsonToHTML(json, wrapperDom, containerWidth) {
      if (containerWidth === void 0) {
        containerWidth = 0;
      }

      // json解析
      if (typeof json === 'string') {
        try {
          json = JSON.parse(json);
        } catch (e) {
          if (isDev) throw new Error('json type error');
          return '';
        }
      }

      var tree = this.jsonToDomTree(json);
      var html = this.renderDomTreeHTML(tree, this.platform, containerWidth); // ssr环境或者editor直接返回html

      if (isSSR || this.platform === 'editor') {
        return html;
      }

      if (wrapperDom) {
        wrapperDom.classList.add('huazhi', "huazhi-" + this.platform);
        wrapperDom.innerHTML = html;
      } // 移动端初始化


      if (this.lazyLoad) {
        this.bindImageLazyLoad();
      }

      if (this.initEvents && typeof this.initEvents === 'function') {
        this.initEvents();
      }

      return wrapperDom ? wrapperDom : html;
    }
    /**
     * 解析表情
     * @param {string} 原始文本
     * @return {array<object|string>} 表情字符串数组
     */
    ;

    _proto.parseEmoji = function parseEmoji(text) {
      if (typeof text !== 'string') return '';
      var results = [];
      var splitIndex = 0;
      var tmp;

      while (tmp = validEmoji.exec(text)) {
        var _tmp = tmp,
            emojiName = _tmp[0],
            startIndex = _tmp.index;
        var lastIndex = validEmoji.lastIndex; // 若表情存在

        if (EMOJIMAP[emojiName]) {
          results.push(text.substring(splitIndex, startIndex));
          results.push({
            tag: 'i',
            props: {
              emoji: emojiName,
              url: EMOJIMAP[emojiName].url
            },
            attr: {}
          }); // 修改下次截取位置

          splitIndex = lastIndex;
        }
      } // 末尾处理


      if (splitIndex < text.length) {
        results.push(text.substring(splitIndex));
      }

      return results;
    }
    /**
     * 解析行内文本
     * @param {array<object>} 行内文本数组
     */
    ;

    _proto.parseInline = function parseInline(inlineList) {
      var results = [];

      for (var j = 0, l = inlineList.length; j < l; j++) {
        var inline = inlineList[j];

        if (inline.type === 'string') {
          if (j === inlineList.length - 1) {
            inline.content = inline.content.slice(0, -1);
          }

          if (inline.bold === 1) {
            // 加粗文本
            results.push({
              tag: 'b',
              attr: {},
              content: inline.content
            });
          } else {
            // 纯文本
            results.push.apply(results, this.parseEmoji(inline.content));
          }
        } else if (inline.type === 'link') {
          results.push({
            tag: 'a',
            props: Object.assign({}, inline)
          });
        }
      }

      return results;
    }
    /**
     * 校验是否合法图片
     * @param {object} image 上传获得image对象
     * @return {boolean} 检测结果
     */
    ;

    _proto.isImage = function isImage(image) {
      return isObject$1(image) && typeof image.url === 'string' && validImageRegexp.test(image.url);
    }
    /**
     * html => json
     * 富文本编辑内容格式化
     * @param {string|object} source html字符串/detail结构
     * @param {boolean} isOps 是否quill的detail结构
     * @param {boolean} isJSonString 是否转为json-string
     * @return {array<object>} j
     */
    ;

    _proto.htmlToJSON = function htmlToJSON(source, isOps, isJSonString) {
      if (isJSonString === void 0) {
        isJSonString = true;
      }

      if (isUndefined(source) || !isString(source) && !isArray(source)) {
        if (isDev) throw new Error('source must be a string type or quill detail');
        return isJSonString ? '[]' : [];
      }

      var results = [];
      return results;
    };

    return Parse;
  }();

  var routes = {
    article: {
      route: '/app/article/detail',
      id: 'aid'
    },
    topic: {
      route: '/app/topic/detail',
      id: 'topicId'
    }
  }; // const getClientRoute = (type) => {
  //
  //
  //   return o[type]
  // };

  var getId = function getId(url) {
    var str = url.split('?')[0].split('/').pop();
    return str.slice(0, -5);
  };

  var WebRich =
  /*#__PURE__*/
  function (_Parse) {
    _inheritsLoose(WebRich, _Parse);

    function WebRich(option) {
      return _Parse.call(this, option) || this;
    }

    var _proto = WebRich.prototype;

    _proto.renderImage = function renderImage(props) {
      // 适配quill自定义图片样式
      return "<div class=\"huazhi-image\" image=" + JSON.stringify(props) + " value=" + props.desc + "></div>";
    };

    _proto.renderLink = function renderLink(props) {
      // return `<p><a href="${props.route.webURL}" target="_blank">${props.content}</a></p>`;
      return "<a class=\"huazhi-link\" target=\"_blank\" href=\"" + props.route.webURL + "\">" + props.content + "</a>";
    }
    /**
     * ops => json
     * 富文本编辑内容格式化
     * @param {object} source html字符串/detail结构
     * @param {boolean} isJSonString 是否转为json-string
     * @return {array<object>|string} json结构
     */
    ;

    _proto.opsToHTML = function opsToHTML(source, isJSonString) {
      if (isJSonString === void 0) {
        isJSonString = false;
      }

      var results = [];
      var tmp = null;

      for (var i = 0, l = source.length; i < l; i++) {
        var _source$i = source[i],
            insert = _source$i.insert,
            _source$i$attributes = _source$i.attributes,
            attributes = _source$i$attributes === void 0 ? {} : _source$i$attributes; // 文本

        if (typeof insert === 'string') {
          var bold = attributes.bold,
              header = attributes.header,
              blockquote = attributes.blockquote;

          if (!tmp) {
            tmp = {
              type: 'text',
              value: []
            };
          } // 标题或者引用


          if (header === 1 || blockquote === true) {
            var lastLine = helperGetLastLIne(tmp.value);

            if (tmp.value.length) {
              results.push(tmp);
            }

            tmp = null;
            var block = {
              type: 'text',
              value: lastLine
            };
            if (header === 1) block.head = 1;
            if (blockquote === true) block.block = 1;
            results.push(block);
          } else if (bold) {
            tmp.value.push({
              type: 'string',
              bold: 1,
              content: insert
            });
          } else {
            tmp.value.push({
              type: 'string',
              content: insert
            });
          } // 非文本

        } else if (isObject$1(insert)) {
          // 清理文本
          if (tmp && tmp.value.length) {
            results.push(tmp);
            tmp = null;
          } // 图片提取


          if (insert.image && this.isImage(insert.image)) {
            results.push(Object.assign({}, insert.image, {
              type: 'image'
            }));
          } // 链接处理


          if (insert.link && isObject$1(insert.link)) {
            var _params;

            // 重命名原始type
            // insert.link.category = insert.link.type;
            var info = routes[insert.link.type];
            var o = {
              type: 'text',
              value: [{
                type: 'link',
                content: insert.link.text,
                route: {
                  route: info.route,
                  webURL: insert.link.url,
                  params: (_params = {}, _params[info.id] = getId(insert.link.url), _params)
                }
              }]
            };
            results.push(o);
          } // 分割线


          if (insert.hr === true) {
            results.push({
              type: 'line'
            });
          }
        } // 末尾不考虑其他因素


        if (i === l - 1 && tmp) {
          results.push(tmp);
        }
      }

      return isJSonString ? JSON.stringify(results) : results;
    };

    return WebRich;
  }(Parse);

  return WebRich;

}));
