// import { isObject } from './utils';

/**
 * 计算图片宽高
 * @param {number} width
 * @param {number} height
 * @param {number} containerWidth
 * @return {object<widht: number, height: number>}
 */
export function computedImageSize(width, height, containerWidth) {
  if (width <= containerWidth) {
    return { width, height };
  } else {
    return {
      width: containerWidth,
      height: parseInt((height / width) * containerWidth, 10)
    };
  }
}

/**
 * 获得文本块最后一行，并移除
 * @parma {array<object>} 文本块
 * @return {array<object>} 最后一行
 */
export function helperGetLastLIne(textList) {
  let results = [];

  for (let i = textList.length - 1; i >= 0; i--) {
    let inlineText = textList[i].content;
    let match = inlineText.match(/\n(.*?)$/);
    if (match) {
      let { 1: matched, index } = match;

      // 后置文本清理
      textList[i].content = inlineText.substr(0, index);
      results.push({ ...textList[i], content: matched });

      break;
    } else {
      results.push(textList[i]);
      // 清理textList末尾
      textList.pop();
    }
  }
  return results.reverse();
}

/**
 * 事件绑定
 * @param {HTMLElement} el 绑定dom
 * @param {string} event 事件名
 * @param {function} func 回调函数
 * @return {function} 解绑函数
 */
export function addEvent(el, event, func) {
  const callback = e => func(e);
  el.addEventListener(event, callback);
  return () => el.removeEventListener(event, callback);
}
