const babel = require('rollup-plugin-babel');
const json = require('rollup-plugin-json');
const commonjs = require('rollup-plugin-commonjs');
const resolve = require('rollup-plugin-node-resolve');
const fs = require('fs');
const path = require('path');
const sass = require('node-sass');

const resolveFile = (file, dir) => {
  return path.join(__dirname, dir, file);
};

const isDev = process.env.NODE_ENV === 'development';

const inputs = ['web.js', 'editor.js', 'mobile.js', 'webview.js'];

const cssFile = resolveFile('article.scss', 'css');

sassCompiler(cssFile)

if (isDev) {
  fs.watchFile(cssFile, function() {
    sassCompiler(cssFile)
  });
}

function sassCompiler(file) {
  console.log('样式文件编译中...')
  const cssResult = sass.renderSync({
    file,
    outputStyle: 'compressed'
  });
  fs.writeFileSync('./dist/article.css', cssResult.css, 'utf-8');
  console.log('样式文件编译完成')
}

export default inputs.map(input => ({
  input: resolveFile(input, 'entry'),
  output: {
    file: resolveFile(input, 'dist'),
    name: 'rich',
    format: 'umd'
  },
  plugins: [
    resolve(),
    commonjs(),
    babel({ exclude: 'node_modules/**' }),
    json()
  ]
}));
